@@ -1,5 +1,5 @@
 "plot.jointPenal" <-
-function (x, event="both", type.plot="hazard", conf.bands=FALSE, ...) 
+function (x, event="both", type.plot="hazard", conf.bands=FALSE, pos.legend="topright", cex.legend=0.7, ylim, main, ...) 
 {
   
    event.type <- charmatch(event, c("both", "recurrent", "terminal"), nomatch = 0)
@@ -15,23 +15,35 @@ function (x, event="both", type.plot="hazard", conf.bands=FALSE, ...)
     }
 
 
+  if(missing(main))
+   main<-"" 
+
   if (event.type==1)
     {
      if(plot.type==1)
       {
-        yymax<-max(c(x$lam, x$lam2),na.rm=TRUE)
-        yymin<-min(c(x$lam, x$lam2),na.rm=TRUE)
+       if (missing(ylim))
+        {
+         yymax<-max(c(x$lam, x$lam2),na.rm=TRUE)
+         yymin<-min(c(x$lam, x$lam2),na.rm=TRUE)
+        }
+       else
+        {
+         yymax<-ylim[2] 
+         yymin<-ylim[1]
+        }
+
         if (conf.bands)
           {
             matplot(x$x1, x$lam, col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ylim=c(yymin,yymax), ...)
+                ylab="Hazard function", ylim=c(yymin,yymax), main=main, ...)
             matlines(x$x2, x$lam2, col="blue", type="l", lty=c(1,2,2), ...)
            }
 
         else
           {
             plot(x$x1, x$lam[,1], col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ylim=c(yymin,yymax), ...)
+                ylab="Hazard function", ylim=c(yymin,yymax), main=main,...)
 
             lines(x$x2, x$lam2[,1], col="blue", type="l", lty=c(1,2,2), xlab="Time",
                 ylab="Hazard function", ...)
@@ -40,41 +52,57 @@ function (x, event="both", type.plot="hazard", conf.bands=FALSE, ...)
     
      else
       {
+
+       if (missing(ylim))
+        {
+         yymax<-1
+         yymin<-0
+        }
+       else
+        {
+         yymax<-ylim[2] 
+         yymin<-ylim[1]
+        }
+
         if (conf.bands)
          {
            matplot(x$x1, x$surv, col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ylim=c(0,1), ...)
+                ylab="Baseline survival function", ylim=c(yymin,yymax), main=main,...)
            matlines(x$x2, x$surv2, col="blue", type="l", lty=c(1,2,2), ...)
          } 
         
         else
          {        
            plot(x$x1, x$surv[,1], col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ylim=c(0,1), ...)
+                ylab="Baseline survival function", ylim=c(yymin,yymax), main=main,...)
            lines(x$x2, x$surv2[,1], col="blue", type="l", lty=c(1,2,2), ...)
          }
 
       }        
-        legend("topright",c("recurrent events", "terminal event"), lty=c(1,1),col=c("red","blue"),xjust=1)
+        legend(pos.legend, c("recurrent events", "terminal event"), lty=c(1,1),col=c("red","blue"), xjust=1, cex=cex.legend, ...)
 
    }
 
 
   if (event.type==2)
     {
+
+     if (missing(ylim))
+      ylim <- c(0,1)
+
      if(plot.type==1)
       {
 
         if (conf.bands)
           {
             matplot(x$x1, x$lam, col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ...)
+                ylab="Hazard function", ylim=ylim, main=main,...)
            }
 
         else
           {
             plot(x$x1, x$lam[,1], col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ...)
+                ylab="Hazard function", ylim=ylim, main=main,...)
           } 
       }        
     
@@ -83,17 +111,17 @@ function (x, event="both", type.plot="hazard", conf.bands=FALSE, ...)
         if (conf.bands)
          {
            matplot(x$x1, x$surv, col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ylim=c(0,1), ...)
+                ylab="Baseline survival function", ylim=ylim, main=main,...)
          } 
         
         else
          {        
            plot(x$x1, x$surv[,1], col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ylim=c(0,1), ...)
+                ylab="Baseline survival function", ylim=ylim, main=main,...)
          }
 
       }        
-        legend("topright",c("recurrent events"), lty=c(1),col=c("red"),xjust=1)
+        legend(pos.legend, c("recurrent events"), lty=c(1),col=c("red"), xjust=1, cex=cex.legend, ...)
    }
 
 
@@ -101,19 +129,23 @@ function (x, event="both", type.plot="hazard", conf.bands=FALSE, ...)
 
   if (event.type==3)
     {
+
+     if (missing(ylim))
+      ylim <- c(0,1)
+
      if(plot.type==1)
       {
 
         if (conf.bands)
           {
             matplot(x$x1, x$lam2, col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ...)
+                ylab="Hazard function", ylim=ylim, main=main,...)
            }
 
         else
           {
             plot(x$x1, x$lam2[,1], col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ...)
+                ylab="Hazard function", ylim=ylim, main=main,...)
           } 
       }        
     
@@ -122,21 +154,19 @@ function (x, event="both", type.plot="hazard", conf.bands=FALSE, ...)
         if (conf.bands)
          {
            matplot(x$x1, x$surv2, col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ylim=c(0,1), ...)
+                ylab="Baseline survival function", ylim=ylim, main=main,...)
          } 
         
         else
          {        
            plot(x$x1, x$surv2[,1], col="red", type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ylim=c(0,1), ...)
+                ylab="Baseline survival function", ylim=ylim, main=main,...)
          }
 
       }        
-        legend("topright",c("terminal event"), lty=c(1),col=c("red"),xjust=1)
+        legend(pos.legend, c("terminal event"), lty=c(1), col=c("red"), xjust=1, cex=cex.legend,...)
    }
 
 
-
-
     return(invisible())
 }
